# -*- coding: utf-8 -*-

from django.contrib import admin

from .models import (
   UserPasswordHistory,
)


@admin.register(UserPasswordHistory)
class UserPasswordHistoryAdmin(admin.ModelAdmin):
    pass






# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.views.generic import TemplateView

from . import views


app_name = 'django_password_history'
urlpatterns = [
    url(
        regex="^UserPasswordHistory/~create/$",
        view=views.UserPasswordHistoryCreateView.as_view(),
        name='UserPasswordHistory_create',
    ),
    url(
        regex="^UserPasswordHistory/(?P<pk>\d+)/~delete/$",
        view=views.UserPasswordHistoryDeleteView.as_view(),
        name='UserPasswordHistory_delete',
    ),
    url(
        regex="^UserPasswordHistory/(?P<pk>\d+)/$",
        view=views.UserPasswordHistoryDetailView.as_view(),
        name='UserPasswordHistory_detail',
    ),
    url(
        regex="^UserPasswordHistory/(?P<pk>\d+)/~update/$",
        view=views.UserPasswordHistoryUpdateView.as_view(),
        name='UserPasswordHistory_update',
    ),
    url(
        regex="^UserPasswordHistory/$",
        view=views.UserPasswordHistoryListView.as_view(),
        name='UserPasswordHistory_list',
    ),
	]



# -*- coding: utf-8 -*-
from django.views.generic import (
    CreateView,
    DeleteView,
    DetailView,
    UpdateView,
    ListView
)

from .models import (
	UserPasswordHistory,
)


class UserPasswordHistoryCreateView(CreateView):

    model = UserPasswordHistory


class UserPasswordHistoryDeleteView(DeleteView):

    model = UserPasswordHistory


class UserPasswordHistoryDetailView(DetailView):

    model = UserPasswordHistory


class UserPasswordHistoryUpdateView(UpdateView):

    model = UserPasswordHistory


class UserPasswordHistoryListView(ListView):

    model = UserPasswordHistory




# Generated by Django 2.2.9 on 2021-06-21 15:48

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserPasswordHistory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password_1', models.CharField(blank=True, max_length=128, null=True)),
                ('password_2', models.CharField(blank=True, max_length=128, null=True)),
                ('password_3', models.CharField(blank=True, max_length=128, null=True)),
                ('password_4', models.CharField(blank=True, max_length=128, null=True)),
                ('password_5', models.CharField(blank=True, max_length=128, null=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django.db import models
from django.conf import settings
from django.apps import apps
from django.contrib.auth.hashers import make_password, check_password


class UserPasswordHistory(models.Model):
    user = models.OneToOneField(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
    password_1 = models.CharField(blank=True, null=True, max_length=128)
    password_2 = models.CharField(blank=True, null=True, max_length=128)
    password_3 = models.CharField(blank=True, null=True, max_length=128)
    password_4 = models.CharField(blank=True, null=True, max_length=128)
    password_5 = models.CharField(blank=True, null=True, max_length=128)
    updated_at = models.DateTimeField(auto_now=True)

    def password_is_used(self, password):
        if settings.PREVIOUS_PASSWORD_COUNT:
            previous_passwords_count = settings.PREVIOUS_PASSWORD_COUNT
        else:
            previous_passwords_count = 5

        if previous_passwords_count:
            for x in range(1, min(previous_passwords_count, 5) + 1):
                f = getattr(self, f'password_{x}', None)
                if f is not None and check_password(password, f):
                    return True

        return False

    def store_password(self):
        self.password_5 = self.password_4
        self.password_4 = self.password_3
        self.password_3 = self.password_2
        self.password_2 = self.password_1
        self.password_1 = self.user.password
        self.save()
